This is a package to apply TOPSIS method to an input file of type ".csv". \
Rules:
1. The input file must have at least 3 columns, i.e. at least 2 Parameters
2. Example for running it on script : \
   python 401903027-topsis.py data.csv '1,2,2,1' '+,-,-,+' output-401903027.csv
3. Pandas should be re-installed.

Created by -  
Paras Tandon \
401903027\
TIET